@@ -19,13 +19,16 @@ module Data.SBV.Dynamic
   -- *** Abstract symbolic value type
     SVal
   , HasKind(..), Kind(..), CW(..), CWVal(..), cwToBool
-  -- *** Arrays of symbolic values
+  -- *** SMT Arrays of symbolic values
   , SArr, readSArr, writeSArr, mergeSArr, newSArr, eqSArr
+  -- *** Functional arrays of symbolic values
+  , SFunArr, readSFunArr, writeSFunArr, mergeSFunArr, newSFunArr
 
   -- ** Creating a symbolic variable
   , Symbolic
   , Quantifier(..)
   , svMkSymVar
+  , sWordN, sWordN_, sIntN, sIntN_
   -- ** Operations on symbolic values
   -- *** Boolean literals
   , svTrue, svFalse, svBool, svAsBool
@@ -109,7 +112,7 @@ module Data.SBV.Dynamic
   -- ** Code generation with uninterpreted functions
   , cgAddPrototype, cgAddDecl, cgAddLDFlags, cgIgnoreSAssert
 
-  -- ** Code generation with 'SInteger' and 'SReal' types
+  -- ** Code generation with 'Data.SBV.SInteger' and 'Data.SBV.SReal' types
   , cgIntegerSize, cgSRealType, CgSRealType(..)
 
   -- ** Compilation to C
@@ -119,7 +122,7 @@ module Data.SBV.Dynamic
   , generateSMTBenchmark
   ) where
 
-import Data.Map (Map)
+import Data.Map.Strict (Map)
 
 import Data.SBV.Core.Kind
 import Data.SBV.Core.Concrete
@@ -206,6 +209,6 @@ getModelAssignment :: SMTResult -> Either String (Bool, [CW])
 getModelAssignment = SBV.getModelAssignment
 
 -- | Extract a model dictionary. Extract a dictionary mapping the variables to
--- their respective values as returned by the SMT solver. Also see `getModelDictionaries`.
+-- their respective values as returned by the SMT solver. Also see `Data.SBV.SMT.getModelDictionaries`.
 getModelDictionary :: SMTResult -> Map String CW
 getModelDictionary = SBV.getModelDictionary
