@@ -36,6 +36,9 @@ z3 = SMTSolver {
                               , supportsPseudoBooleans     = True
                               , supportsCustomQueries      = True
                               , supportsGlobalDecls        = True
+                              , supportsFlattenedSequences = Just [ "(set-option :pp.max_depth      4294967295)"
+                                                                  , "(set-option :pp.min_alias_size 4294967295)"
+                                                                  ]
                               }
          }
 
