@@ -46,7 +46,7 @@ genTest n m = gen 0 []
                        gen (i+1) (t:sofar)
         tc = do (_, Result {resTraces=tvals, resConsts=cs, resConstraints=cstrs, resOutputs=os}) <- runSymbolic Concrete (m >>= output)
                 let cval = fromMaybe (error "Cannot generate tests in the presence of uninterpeted constants!") . (`lookup` cs)
-                    cond = all (cwToBool . cval . snd) cstrs
+                    cond = and [cwToBool (cval v) | (False, _, v) <- cstrs] -- Only pick-up "hard" constraints, as indicated by False in the fist component
                 if cond
                    then return (map snd tvals, map cval os)
                    else tc   -- try again, with the same set of constraints
@@ -112,6 +112,7 @@ haskell vname vs = intercalate "\n" $ [ "-- Automatically generated by SBV. Do n
         valOf  []    = "()"
         valOf  [x]   = s x
         valOf  xs    = "[" ++ intercalate ", " (map s xs) ++ "]"
+
         t cw = case kindOf cw of
                  KBool             -> "Bool"
                  KBounded False 8  -> "Word8"
@@ -125,16 +126,23 @@ haskell vname vs = intercalate "\n" $ [ "-- Automatically generated by SBV. Do n
                  KUnbounded        -> "Integer"
                  KFloat            -> "Float"
                  KDouble           -> "Double"
+                 KChar             -> error "SBV.renderTest: Unsupported char"
+                 KString           -> error "SBV.renderTest: Unsupported string"
                  KReal             -> error $ "SBV.renderTest: Unsupported real valued test value: " ++ show cw
+                 KList es          -> error $ "SBV.renderTest: Unsupported list valued test: [" ++ show es ++ "]"
                  KUserSort us _    -> error $ "SBV.renderTest: Unsupported uninterpreted sort: " ++ us
                  _                 -> error $ "SBV.renderTest: Unexpected CW: " ++ show cw
+
         s cw = case kindOf cw of
                   KBool             -> take 5 (show (cwToBool cw) ++ repeat ' ')
                   KBounded sgn   sz -> let CWInteger w = cwVal cw in shex  False True (sgn, sz) w
                   KUnbounded        -> let CWInteger w = cwVal cw in shexI False True           w
                   KFloat            -> let CWFloat w   = cwVal cw in showHFloat w
                   KDouble           -> let CWDouble w  = cwVal cw in showHDouble w
+                  KChar             -> error "SBV.renderTest: Unsupported char"
+                  KString           -> error "SBV.renderTest: Unsupported string"
                   KReal             -> let CWAlgReal w = cwVal cw in algRealToHaskell w
+                  KList es          -> error $ "SBV.renderTest: Unsupported list valued sort: [" ++ show es ++ "]"
                   KUserSort us _    -> error $ "SBV.renderTest: Unsupported uninterpreted sort: " ++ us
 
 c :: String -> [([CW], [CW])] -> String
@@ -158,13 +166,13 @@ c n vs = intercalate "\n" $
               , "typedef double SDouble;"
               , ""
               , "/* Unsigned bit-vectors */"
-              , "typedef uint8_t  SWord8 ;"
+              , "typedef uint8_t  SWord8;"
               , "typedef uint16_t SWord16;"
               , "typedef uint32_t SWord32;"
               , "typedef uint64_t SWord64;"
               , ""
               , "/* Signed bit-vectors */"
-              , "typedef int8_t  SInt8 ;"
+              , "typedef int8_t  SInt8;"
               , "typedef int16_t SInt16;"
               , "typedef int32_t SInt32;"
               , "typedef int64_t SInt64;"
@@ -212,6 +220,8 @@ c n vs = intercalate "\n" $
                         KBounded True  64 -> "SInt64"
                         KFloat            -> "SFloat"
                         KDouble           -> "SDouble"
+                        KChar             -> error "SBV.renderTest: Unsupported char"
+                        KString           -> error "SBV.renderTest: Unsupported string"
                         KUnbounded        -> error "SBV.renderTest: Unbounded integers are not supported when generating C test-cases."
                         KReal             -> error "SBV.renderTest: Real values are not supported when generating C test-cases."
                         KUserSort us _    -> error $ "SBV.renderTest: Unsupported uninterpreted sort: " ++ us
@@ -219,10 +229,13 @@ c n vs = intercalate "\n" $
         mkLine (is, os) = "{{" ++ intercalate ", " (map v is) ++ "}, {" ++ intercalate ", " (map v os) ++ "}}"
         v cw = case kindOf cw of
                   KBool           -> if cwToBool cw then "true " else "false"
-                  KBounded sgn sz -> let CWInteger w = cwVal cw in shex  False True (sgn, sz) w
+                  KBounded sgn sz -> let CWInteger w = cwVal cw in chex  False True (sgn, sz) w
                   KUnbounded      -> let CWInteger w = cwVal cw in shexI False True           w
                   KFloat          -> let CWFloat w   = cwVal cw in showCFloat w
                   KDouble         -> let CWDouble w  = cwVal cw in showCDouble w
+                  KChar           -> error "SBV.renderTest: Unsupported char"
+                  KString         -> error "SBV.renderTest: Unsupported string"
+                  k@KList{}       -> error $ "SBV.renderTest: Unsupported list sort!" ++ show k
                   KUserSort us _  -> error $ "SBV.renderTest: Unsupported uninterpreted sort: " ++ us
                   KReal           -> error "SBV.renderTest: Real values are not supported when generating C test-cases."
         outLine
@@ -249,6 +262,8 @@ c n vs = intercalate "\n" $
                     KBounded True  64 -> "%\"PRId64\"LL"
                     KFloat            -> "%f"
                     KDouble           -> "%f"
+                    KChar             -> error "SBV.renderTest: Unsupported char"
+                    KString           -> error "SBV.renderTest: Unsupported string"
                     KUnbounded        -> error "SBV.renderTest: Unsupported unbounded integers for C generation."
                     KReal             -> error "SBV.renderTest: Unsupported real valued values for C generation."
                     _                 -> error $ "SBV.renderTest: Unexpected CW: " ++ show cw
@@ -269,25 +284,32 @@ forte vname bigEndian ss vs = intercalate "\n" $ [ "// Automatically generated b
          | True      = "rev (map (\\s. s == \"1\") (explode (string_tl r)))"
         toF True  = '1'
         toF False = '0'
-        blast cw = case kindOf cw of
-                     KBool             -> [toF (cwToBool cw)]
-                     KBounded False 8  -> xlt  8 (cwVal cw)
-                     KBounded False 16 -> xlt 16 (cwVal cw)
-                     KBounded False 32 -> xlt 32 (cwVal cw)
-                     KBounded False 64 -> xlt 64 (cwVal cw)
-                     KBounded True 8   -> xlt  8 (cwVal cw)
-                     KBounded True 16  -> xlt 16 (cwVal cw)
-                     KBounded True 32  -> xlt 32 (cwVal cw)
-                     KBounded True 64  -> xlt 64 (cwVal cw)
-                     KFloat            -> error "SBV.renderTest: Float values are not supported when generating Forte test-cases."
-                     KDouble           -> error "SBV.renderTest: Double values are not supported when generating Forte test-cases."
-                     KReal             -> error "SBV.renderTest: Real values are not supported when generating Forte test-cases."
-                     KUnbounded        -> error "SBV.renderTest: Unbounded integers are not supported when generating Forte test-cases."
-                     _                 -> error $ "SBV.renderTest: Unexpected CW: " ++ show cw
-        xlt s (CWInteger v)   = [toF (testBit v i) | i <- [s-1, s-2 .. 0]]
-        xlt _ (CWFloat r)     = error $ "SBV.renderTest.Forte: Unexpected float value: " ++ show r
-        xlt _ (CWDouble r)    = error $ "SBV.renderTest.Forte: Unexpected double value: " ++ show r
-        xlt _ (CWAlgReal r)   = error $ "SBV.renderTest.Forte: Unexpected real value: " ++ show r
+        blast cw = let noForte w = error "SBV.renderTest: " ++ w ++ " values are not supported when generating Forte test-cases."
+                   in case kindOf cw of
+                       KBool             -> [toF (cwToBool cw)]
+                       KBounded False 8  -> xlt  8 (cwVal cw)
+                       KBounded False 16 -> xlt 16 (cwVal cw)
+                       KBounded False 32 -> xlt 32 (cwVal cw)
+                       KBounded False 64 -> xlt 64 (cwVal cw)
+                       KBounded True 8   -> xlt  8 (cwVal cw)
+                       KBounded True 16  -> xlt 16 (cwVal cw)
+                       KBounded True 32  -> xlt 32 (cwVal cw)
+                       KBounded True 64  -> xlt 64 (cwVal cw)
+                       KFloat            -> noForte "Float"
+                       KDouble           -> noForte "Double"
+                       KChar             -> noForte "Char"
+                       KString           -> noForte "String"
+                       KReal             -> noForte "Real"
+                       KList ek          -> noForte $ "List of " ++ show ek
+                       KUnbounded        -> noForte "Unbounded integers"
+                       _                 -> error $ "SBV.renderTest: Unexpected CW: " ++ show cw
+        xlt s (CWInteger  v)  = [toF (testBit v i) | i <- [s-1, s-2 .. 0]]
+        xlt _ (CWFloat    r)  = error $ "SBV.renderTest.Forte: Unexpected float value: "         ++ show r
+        xlt _ (CWDouble   r)  = error $ "SBV.renderTest.Forte: Unexpected double value: "        ++ show r
+        xlt _ (CWChar     r)  = error $ "SBV.renderTest.Forte: Unexpected char value: "          ++ show r
+        xlt _ (CWString   r)  = error $ "SBV.renderTest.Forte: Unexpected string value: "        ++ show r
+        xlt _ (CWAlgReal  r)  = error $ "SBV.renderTest.Forte: Unexpected real value: "          ++ show r
+        xlt _ CWList{}        = error   "SBV.renderTest.Forte: Unexpected list value!"
         xlt _ (CWUserSort r)  = error $ "SBV.renderTest.Forte: Unexpected uninterpreted value: " ++ show r
         mkLine  (i, o) = "("  ++ mkTuple (form (fst ss) (concatMap blast i)) ++ ", " ++ mkTuple (form (snd ss) (concatMap blast o)) ++ ")"
         mkTuple []  = "()"
