@@ -17,17 +17,22 @@ module TestSuite.Basics.AllSat(tests) where
 import Data.Generics
 import Utils.SBVTestFramework
 
+import Data.List (sortOn)
+
 tests :: TestTree
 tests =
   testGroup "Basics.AllSat"
     [ goldenVsStringShow "allSat1" t1
     , goldenVsStringShow "allSat2" t2
-    , goldenVsStringShow "allSat3" $ allSat $ \x -> x .== (0::SFloat)
-    , goldenVsStringShow "allSat4" $ allSat $ \x -> x .<  (0::SWord8)
-    , goldenVsStringShow "allSat5" $ allSat $ \x y -> x .< y &&& y .< (4::SWord8)
-    , goldenVsStringShow "allSat6" $ allSat $ exists "x" >>= \x -> exists "y" >>= \y -> forall "z" >>= \z -> return (x .< (y::SWord8) &&& y .< 3 &&& z .== (z::SWord8))
+    , goldenVsStringShow "allSat3" $            allSat $ \x -> x .== (0::SFloat)
+    , goldenVsStringShow "allSat4" $            allSat $ \x -> x .<  (0::SWord8)
+    , goldenVsStringShow "allSat5" $ fmap srt $ allSat $ \x y -> x .< y &&& y .< (4::SWord8)
+    , goldenVsStringShow "allSat6" $            allSat $ exists "x" >>= \x -> exists "y" >>= \y -> forall "z" >>= \z -> return (x .< (y::SWord8) &&& y .< 3 &&& z .== (z::SWord8))
     ]
 
+srt :: AllSatResult -> AllSatResult
+srt (AllSatResult (b1, b2, rs)) = AllSatResult (b1, b2, sortOn getModelDictionary rs)
+
 newtype Q = Q () deriving (Eq, Ord, Data, Read, Show, SymWord, HasKind)
 type SQ = SBV Q
 
