@@ -6,13 +6,13 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.BitPrecise.MergeSort
+-- Test suite for Documentation.SBV.Examples.BitPrecise.MergeSort
 -----------------------------------------------------------------------------
 
 module TestSuite.BitPrecise.MergeSort(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.BitPrecise.MergeSort
+import Documentation.SBV.Examples.BitPrecise.MergeSort
 
 import Utils.SBVTestFramework
 
@@ -21,7 +21,7 @@ tests :: TestTree
 tests = testGroup "BitPrecise.MergeSort" [
    goldenVsStringShow "merge" mergeC
  ]
- where mergeC = compileToC' "merge" $ do
+ where mergeC = snd <$> compileToC' "merge" (do
                    cgSetDriverValues [10, 6, 4, 82, 71]
                    xs <- cgInputArr 5 "xs"
-                   cgOutputArr "ys" (mergeSort xs)
+                   cgOutputArr "ys" (mergeSort xs))
