@@ -6,13 +6,13 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.CodeGeneration.AddSub
+-- Test suite for Documentation.SBV.Examples.CodeGeneration.AddSub
 -----------------------------------------------------------------------------
 
 module TestSuite.CodeGeneration.AddSub(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.CodeGeneration.AddSub
+import Documentation.SBV.Examples.CodeGeneration.AddSub
 
 import Utils.SBVTestFramework
 
@@ -21,11 +21,11 @@ tests :: TestTree
 tests = testGroup "CodeGen.addSub" [
    goldenVsStringShow "addSub" code
  ]
- where code = compileToC' "addSub" $ do
+ where code = snd <$> compileToC' "addSub" (do
                 cgSetDriverValues [76, 92]
                 cgPerformRTCs True
                 x <- cgInput "x"
                 y <- cgInput "y"
                 let (s, d) = addSub x y
                 cgOutput "sum" s
-                cgOutput "dif" d
+                cgOutput "dif" d)
