@@ -6,13 +6,13 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.CodeGeneration.CRC_USB5
+-- Test suite for Documentation.SBV.Examples.CodeGeneration.CRC_USB5
 -----------------------------------------------------------------------------
 
 module TestSuite.CodeGeneration.CRC_USB5(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.CodeGeneration.CRC_USB5
+import Documentation.SBV.Examples.CodeGeneration.CRC_USB5
 
 import Utils.SBVTestFramework
 
@@ -22,7 +22,7 @@ tests = testGroup "CRC.CodeGen" [
    goldenVsStringShow "crcUSB5_1" $ genC crcUSB
  , goldenVsStringShow "crcUSB5_2" $ genC crcUSB'
  ]
- where genC f = compileToC' "crcUSB5" $ do
+ where genC f = snd <$> compileToC' "crcUSB5" (do
                    cgSetDriverValues [0xFEDC]
                    msg <- cgInput "msg"
-                   cgReturn $ f msg
+                   cgReturn $ f msg)
