@@ -6,13 +6,13 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.CodeGeneration.GCD
+-- Test suite for Documentation.SBV.Examples.CodeGeneration.GCD
 -----------------------------------------------------------------------------
 
 module TestSuite.CodeGeneration.GCD(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.CodeGeneration.GCD
+import Documentation.SBV.Examples.CodeGeneration.GCD
 
 import Utils.SBVTestFramework
 
@@ -21,8 +21,8 @@ tests :: TestTree
 tests = testGroup "CodeGeneration.GCD" [
    goldenVsStringShow "gcd" gcdC
  ]
- where gcdC = compileToC' "sgcd" $ do
+ where gcdC = snd <$> compileToC' "sgcd" (do
                 cgSetDriverValues [55,154]
                 x <- cgInput "x"
                 y <- cgInput "y"
-                cgReturn $ sgcd x y
+                cgReturn $ sgcd x y)
