@@ -6,13 +6,13 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.CodeGeneration.Uninterpreted
+-- Test suite for Documentation.SBV.Examples.CodeGeneration.Uninterpreted
 -----------------------------------------------------------------------------
 
 module TestSuite.CodeGeneration.Uninterpreted(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.CodeGeneration.Uninterpreted
+import Documentation.SBV.Examples.CodeGeneration.Uninterpreted
 
 import Utils.SBVTestFramework
 
@@ -21,7 +21,6 @@ tests :: TestTree
 tests = testGroup "CodeGeneration.Uninterpreted" [
    goldenVsStringShow "cgUninterpret"  genC
  ]
- where genC = compileToC' "tstShiftLeft" $ do
-                  cgSetDriverValues [1, 2, 3]
-                  [x, y, z] <- cgInputArr 3 "vs"
-                  cgReturn $ tstShiftLeft x y z
+ where genC = snd <$> compileToC' "tstShiftLeft" (do cgSetDriverValues [1, 2, 3]
+                                                     [x, y, z] <- cgInputArr 3 "vs"
+                                                     cgReturn $ tstShiftLeft x y z)
