@@ -6,22 +6,22 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.Crypto.AES
+-- Test suite for Documentation.SBV.Examples.Crypto.AES
 -----------------------------------------------------------------------------
 
 module TestSuite.Crypto.AES(tests) where
 
 import Data.SBV.Internals
-import Data.SBV.Examples.Crypto.AES
+import Documentation.SBV.Examples.Crypto.AES
 
 import Utils.SBVTestFramework
 
 -- Test suite
 tests :: TestTree
 tests = testGroup "Crypto.AES" [
-   goldenVsStringShow "aes128Enc" $ compileToC'    "aes128Enc" (aes128EncDec True)
- , goldenVsStringShow "aes128Dec" $ compileToC'    "aes128Dec" (aes128EncDec False)
- , goldenVsStringShow "aes128Lib" $ compileToCLib' "aes128Lib" aes128Comps
+   goldenVsStringShow "aes128Enc" $ snd <$> compileToC'    "aes128Enc" (aes128EncDec True)
+ , goldenVsStringShow "aes128Dec" $ snd <$> compileToC'    "aes128Dec" (aes128EncDec False)
+ , goldenVsStringShow "aes128Lib" $ snd <$> compileToCLib' "aes128Lib" aes128Comps
  ]
  where aes128EncDec d = do pt  <- cgInputArr 4 "pt"
                            key <- cgInputArr 4 "key"
