@@ -6,12 +6,12 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.Puzzles.Counts
+-- Test suite for Documentation.SBV.Examples.Puzzles.Counts
 -----------------------------------------------------------------------------
 
 module TestSuite.Puzzles.Counts(tests) where
 
-import Data.SBV.Examples.Puzzles.Counts
+import Documentation.SBV.Examples.Puzzles.Counts
 
 import Utils.SBVTestFramework
 
