@@ -6,12 +6,12 @@
 -- Maintainer  :  erkokl@gmail.com
 -- Stability   :  experimental
 --
--- Test suite for Data.SBV.Examples.Puzzles.Euler185
+-- Test suite for Documentation.SBV.Examples.Puzzles.Euler185
 -----------------------------------------------------------------------------
 
 module TestSuite.Puzzles.Euler185(tests) where
 
-import Data.SBV.Examples.Puzzles.Euler185
+import Documentation.SBV.Examples.Puzzles.Euler185
 
 import Utils.SBVTestFramework
 
